@@ -93,8 +93,8 @@ try {
         exit;
     }
 
-    // File system preparation
-    $domain_dir = '/docker/users/' . AUTH_USER . '/' . $primary_domain_row['domain_name'];
+    // File system preparation using actual FQDN for subdomain support
+    $domain_dir = '/docker/users/' . AUTH_USER . '/' . $primary_fqdn;
     if (!file_exists($domain_dir)) {
         if (!mkdir($domain_dir, 0755, true)) {
             http_response_code(500);
@@ -188,13 +188,13 @@ try {
     }
 
     for ($i = 1; $i <= $container_count; $i++) {
-        $container_name = $primary_domain_row['domain_name'] . '-' . str_pad($i, 2, '0', STR_PAD_LEFT);
+        $container_name = $primary_fqdn . '-' . str_pad($i, 2, '0', STR_PAD_LEFT);
         
         // Environment variables
         $env_vars = [
             'WHP_USER=' . AUTH_USER,
             'WHP_UID=' . $uid,
-            'WHP_DOMAIN=' . $primary_domain_row['domain_name'],
+            'WHP_DOMAIN=' . $primary_fqdn,
             'WHP_CONTAINER_NUMBER=' . $i
         ];
 
@@ -208,15 +208,15 @@ try {
             $startup_env = json_decode($container_type_details['startup_env'], true);
             if ($startup_env) {
                 foreach ($startup_env as $var_name => $var_value) {
-                    $var_value = $MySQLMgmt->replaceDynamicVariables($var_value, AUTH_USER, $primary_domain_row['domain_name'], $uid, $i, $container_type_details['listen_port'] ?? 80);
+                    $var_value = $MySQLMgmt->replaceDynamicVariables($var_value, AUTH_USER, $primary_fqdn, $uid, $i, $container_type_details['listen_port'] ?? 80);
                     $env_vars[] = $var_name . '=' . $var_value;
                 }
             }
         }
 
-        // Volumes
+        // Volumes using actual FQDN path
         $volumes = [
-            '/docker/users/' . AUTH_USER . '/' . $primary_domain_row['domain_name'] . ':/var/www/html'
+            '/docker/users/' . AUTH_USER . '/' . $primary_fqdn . ':/var/www/html'
         ];
 
         // Process mount options
@@ -224,8 +224,8 @@ try {
             $mount_options = json_decode($container_type_details['mount_options'], true);
             if ($mount_options && isset($mount_options['volumes'])) {
                 foreach ($mount_options['volumes'] as $volume) {
-                    $source = $MySQLMgmt->replaceDynamicVariables($volume['source'], AUTH_USER, $primary_domain_row['domain_name'], $uid, $i, $container_type_details['listen_port'] ?? 80);
-                    $target = $MySQLMgmt->replaceDynamicVariables($volume['target'], AUTH_USER, $primary_domain_row['domain_name'], $uid, $i, $container_type_details['listen_port'] ?? 80);
+                    $source = $MySQLMgmt->replaceDynamicVariables($volume['source'], AUTH_USER, $primary_fqdn, $uid, $i, $container_type_details['listen_port'] ?? 80);
+                    $target = $MySQLMgmt->replaceDynamicVariables($volume['target'], AUTH_USER, $primary_fqdn, $uid, $i, $container_type_details['listen_port'] ?? 80);
                     $volumes[] = $source . ':' . $target;
                 }
             }
@@ -237,7 +237,7 @@ try {
             'name' => $container_name,
             'labels' => [
                 'whp.user' => AUTH_USER,
-                'whp.domain' => $primary_domain_row['domain_name'],
+                'whp.domain' => $primary_fqdn,
                 'whp.site_id' => strval($site_id),
                 'whp.container_number' => strval($i)
             ],
