@@ -45,13 +45,14 @@ switch ($method) {
                         $stmt = $db->prepare("
                             SELECT 
                                 s.*,
-                                d.domain_name as primary_domain,
+                                COALESCE(sd.fqdn, d.domain_name) as primary_domain,
                                 ct.name as container_type_name,
                                 ct.base_image,
                                 ct.listen_port,
                                 ct.description as container_type_description
                             FROM whp.sites s
                             JOIN whp.domains d ON s.primary_domain_id = d.id
+                            LEFT JOIN whp.site_domains sd ON s.id = sd.site_id AND sd.is_primary = 1
                             JOIN whp.container_types ct ON s.container_type_id = ct.id
                             WHERE s.id = ?
                         ");
@@ -1282,29 +1283,28 @@ switch ($method) {
                             break;
                         }
                         
-                        // Pull the latest image first
-                        $pull_result = $DockerAPI->pull_image($site['base_image']);
-                        if (!$pull_result['success']) {
-                            echo json_encode(array(
-                                'status' => 'error',
-                                'message' => 'Failed to pull latest image: ' . $pull_result['error']
-                            ));
-                            break;
-                        }
+                        // Note: We don't pull the image here - manual recreation uses existing image
                         
-                        // Get all containers for this site
+                        // Get existing containers for this site
                         $stmt = $db->prepare("SELECT * FROM whp.site_containers WHERE site_id = ? ORDER BY container_number ASC");
                         $stmt->execute([$site_id]);
-                        $containers = $stmt->fetchAll();
+                        $existing_containers = $stmt->fetchAll();
                         
-                        if (empty($containers)) {
-                            echo json_encode(array(
-                                'status' => 'error',
-                                'message' => 'No containers found for this site'
-                            ));
-                            break;
+                        // Build array of existing container numbers for easy lookup
+                        $existing_container_numbers = [];
+                        foreach ($existing_containers as $container) {
+                            $existing_container_numbers[] = $container['container_number'];
                         }
                         
+                        // Determine what containers should exist (1 to container_count)
+                        $expected_containers = [];
+                        for ($i = 1; $i <= $site['container_count']; $i++) {
+                            $expected_containers[] = $i;
+                        }
+                        
+                        // Find missing containers that need to be created
+                        $missing_containers = array_diff($expected_containers, $existing_container_numbers);
+                        
                         // Get user UID
                         $uid = trim(shell_exec("id -u " . escapeshellarg($site['username'])));
                         if (!is_numeric($uid)) {
@@ -1316,16 +1316,27 @@ switch ($method) {
                             break;
                         }
                         
-                        $recreated_containers = [];
+                        $processed_containers = [];
                         $errors = [];
                         
-                        foreach ($containers as $container) {
-                            // Stop and remove the old container
-                            $stop_result = $DockerAPI->stop_container($container['container_id']);
-                            $remove_result = $DockerAPI->remove_container($container['container_id']);
+                        // Process all expected containers (both existing and missing)
+                        foreach ($expected_containers as $container_number) {
+                            // Check if this container already exists
+                            $existing_container = null;
+                            foreach ($existing_containers as $container) {
+                                if ($container['container_number'] == $container_number) {
+                                    $existing_container = $container;
+                                    break;
+                                }
+                            }
                             
-                            // Create new container with same configuration
-                            $container_number = $container['container_number'];
+                            // If container exists, stop and remove it first (recreate)
+                            if ($existing_container) {
+                                $stop_result = $DockerAPI->stop_container($existing_container['container_id']);
+                                $remove_result = $DockerAPI->remove_container($existing_container['container_id']);
+                            }
+                            
+                            // Create/recreate the container
                             $container_name = $site['primary_domain'] . '-' . str_pad($container_number, 2, '0', STR_PAD_LEFT);
                             
                             // Prepare environment variables
@@ -1394,21 +1405,30 @@ switch ($method) {
                             $result = $DockerAPI->create_container($container_config);
                             
                             if ($result['success']) {
-                                // Update container info in database
-                                $stmt = $db->prepare("UPDATE whp.site_containers SET container_id = ?, status = 'running' WHERE site_id = ? AND container_number = ?");
-                                $stmt->execute([$result['container_id'], $site_id, $container_number]);
+                                // Update or insert container info in database
+                                if ($existing_container) {
+                                    // Update existing container record
+                                    $stmt = $db->prepare("UPDATE whp.site_containers SET container_id = ?, status = 'active' WHERE site_id = ? AND container_number = ?");
+                                    $stmt->execute([$result['container_id'], $site_id, $container_number]);
+                                } else {
+                                    // Insert new container record
+                                    $stmt = $db->prepare("INSERT INTO whp.site_containers (site_id, container_id, container_number, status) VALUES (?, ?, ?, 'active')");
+                                    $stmt->execute([$site_id, $result['container_id'], $container_number]);
+                                }
                                 
-                                $recreated_containers[] = [
+                                $processed_containers[] = [
                                     'container_number' => $container_number,
-                                    'container_id' => $result['container_id']
+                                    'container_id' => $result['container_id'],
+                                    'action' => $existing_container ? 'recreated' : 'created'
                                 ];
                             } else {
-                                $errors[] = "Failed to recreate container $container_number: " . $result['error'];
+                                $action = $existing_container ? 'recreate' : 'create';
+                                $errors[] = "Failed to $action container $container_number: " . $result['error'];
                             }
                         }
                         
-                        // Configure HAProxy if containers were recreated successfully
-                        if (!empty($recreated_containers)) {
+                        // Configure HAProxy if containers were processed successfully
+                        if (!empty($processed_containers)) {
                             require_once('/docker/whp/web/libs/haproxy_manager.php');
                             $haproxy_manager = new haproxy_manager();
                             $haproxy_result = $haproxy_manager->configureSite($site_id, $site);
@@ -1419,16 +1439,29 @@ switch ($method) {
                         }
                         
                         if (empty($errors)) {
+                            // Count created vs recreated containers for better messaging
+                            $created_count = count(array_filter($processed_containers, function($c) { return $c['action'] === 'created'; }));
+                            $recreated_count = count(array_filter($processed_containers, function($c) { return $c['action'] === 'recreated'; }));
+                            
+                            $message = '';
+                            if ($created_count > 0 && $recreated_count > 0) {
+                                $message = "Created $created_count missing container(s) and recreated $recreated_count existing container(s) with latest images and HAProxy configured";
+                            } else if ($created_count > 0) {
+                                $message = "Created $created_count missing container(s) with latest images and HAProxy configured";
+                            } else {
+                                $message = "Recreated $recreated_count container(s) with latest images and HAProxy configured";
+                            }
+                            
                             echo json_encode(array(
                                 'status' => 'success',
-                                'message' => 'All containers recreated successfully with latest images and HAProxy configured',
-                                'containers' => $recreated_containers
+                                'message' => $message,
+                                'containers' => $processed_containers
                             ));
                         } else {
                             echo json_encode(array(
                                 'status' => 'partial',
-                                'message' => 'Some containers recreated with errors',
-                                'containers' => $recreated_containers,
+                                'message' => 'Some containers processed with errors',
+                                'containers' => $processed_containers,
                                 'errors' => $errors
                             ));
                         }
