@@ -59,12 +59,14 @@ class pgsqlmgmt {
                 return ['status' => '1', 'msg' => 'PostgreSQL user already exists'];
             }
             
-            // Create the user
-            $sql = 'CREATE USER ' . $pdo->quote($username) . ' WITH PASSWORD ' . $pdo->quote($password);
+            // Create the user with proper escaping
+            $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+            $escaped_password = "'" . str_replace("'", "''", $password) . "'";
+            $sql = "CREATE USER $escaped_username WITH PASSWORD $escaped_password";
             $pdo->exec($sql);
             
             // Grant CREATE privilege so user can create databases with their prefix
-            $sql = 'ALTER USER ' . $pdo->quote($username) . ' CREATEDB';
+            $sql = "ALTER USER $escaped_username CREATEDB";
             $pdo->exec($sql);
             
             return ['status' => '0', 'msg' => 'PostgreSQL user created successfully'];
@@ -74,6 +76,45 @@ class pgsqlmgmt {
             return ['status' => '1', 'msg' => 'Failed to create PostgreSQL user: ' . $e->getMessage()];
         }
     }
+
+    /**
+     * Create a PostgreSQL user for SSO without database creation privileges
+     * 
+     * @param string $username The username to create
+     * @param string $password The user's password
+     * @return array Status array with success/error information
+     */
+    public function createPostgreSQLUserForSSO($username, $password) {
+        $pdo = $this->getPostgreSQLConnection();
+        if (!$pdo) {
+            return ['status' => '1', 'msg' => 'Failed to connect to PostgreSQL server'];
+        }
+        
+        try {
+            // Check if user already exists
+            $stmt = $pdo->prepare("SELECT 1 FROM pg_user WHERE usename = ?");
+            $stmt->execute([$username]);
+            if ($stmt->fetch()) {
+                return ['status' => '1', 'msg' => 'PostgreSQL user already exists'];
+            }
+            
+            // Create the user with proper escaping - NO CREATEDB privilege
+            $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+            $escaped_password = "'" . str_replace("'", "''", $password) . "'";
+            $sql = "CREATE USER $escaped_username WITH PASSWORD $escaped_password";
+            $pdo->exec($sql);
+            
+            // Grant CONNECT privilege only - no database creation
+            $sql = "ALTER USER $escaped_username CONNECTION LIMIT -1";
+            $pdo->exec($sql);
+            
+            return ['status' => '0', 'msg' => 'PostgreSQL SSO user created successfully'];
+            
+        } catch (PDOException $e) {
+            error_log("PostgreSQL SSO user creation failed: " . $e->getMessage());
+            return ['status' => '1', 'msg' => 'Failed to create PostgreSQL SSO user: ' . $e->getMessage()];
+        }
+    }
     
     /**
      * Delete a PostgreSQL user
@@ -96,11 +137,12 @@ class pgsqlmgmt {
             }
             
             // Drop owned objects and reassign ownership
-            $sql = 'DROP OWNED BY ' . $pdo->quote($username) . ' CASCADE';
+            $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+            $sql = "DROP OWNED BY $escaped_username CASCADE";
             $pdo->exec($sql);
             
             // Drop the user
-            $sql = 'DROP USER ' . $pdo->quote($username);
+            $sql = "DROP USER $escaped_username";
             $pdo->exec($sql);
             
             return ['status' => '0', 'msg' => 'PostgreSQL user deleted successfully'];
@@ -133,7 +175,9 @@ class pgsqlmgmt {
             }
             
             // Change password
-            $sql = 'ALTER USER ' . $pdo->quote($username) . ' WITH PASSWORD ' . $pdo->quote($new_password);
+            $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+            $escaped_password = "'" . str_replace("'", "''", $new_password) . "'";
+            $sql = "ALTER USER $escaped_username WITH PASSWORD $escaped_password";
             $pdo->exec($sql);
             
             return ['status' => '0', 'msg' => 'PostgreSQL password changed successfully'];
@@ -166,7 +210,9 @@ class pgsqlmgmt {
             }
             
             // Create the database with owner
-            $sql = 'CREATE DATABASE ' . $pdo->quote($database_name) . ' OWNER ' . $pdo->quote($owner_username);
+            $escaped_database = '"' . str_replace('"', '""', $database_name) . '"';
+            $escaped_owner = '"' . str_replace('"', '""', $owner_username) . '"';
+            $sql = "CREATE DATABASE $escaped_database OWNER $escaped_owner";
             $pdo->exec($sql);
             
             return ['status' => '0', 'msg' => 'Database created successfully'];
@@ -207,7 +253,8 @@ class pgsqlmgmt {
             $stmt->execute([$database_name]);
             
             // Drop the database
-            $sql = 'DROP DATABASE ' . $pdo->quote($database_name);
+            $escaped_database = '"' . str_replace('"', '""', $database_name) . '"';
+            $sql = "DROP DATABASE $escaped_database";
             $pdo->exec($sql);
             
             return ['status' => '0', 'msg' => 'Database deleted successfully'];
@@ -245,33 +292,39 @@ class pgsqlmgmt {
             $stmt = $pdo->prepare("SELECT 1 FROM pg_user WHERE usename = ?");
             $stmt->execute([$username]);
             if ($stmt->fetch()) {
-                $sql = 'DROP USER ' . $pdo->quote($username);
+                $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+                $sql = "DROP USER $escaped_username";
                 $pdo->exec($sql);
             }
 
             // Create the user
-            $sql = 'CREATE USER ' . $pdo->quote($username) . ' WITH PASSWORD ' . $pdo->quote($password);
+            $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+            $escaped_password = "'" . str_replace("'", "''", $password) . "'";
+            $sql = "CREATE USER $escaped_username WITH PASSWORD $escaped_password";
             $pdo->exec($sql);
 
             // Grant privileges on database
             if (in_array('ALL', $privileges)) {
                 // Grant all privileges on database
-                $sql = 'GRANT ALL PRIVILEGES ON DATABASE ' . $pdo->quote($database_name) . ' TO ' . $pdo->quote($username);
+                $escaped_database = '"' . str_replace('"', '""', $database_name) . '"';
+                $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+                $sql = "GRANT ALL PRIVILEGES ON DATABASE $escaped_database TO $escaped_username";
                 $pdo->exec($sql);
                 
                 // Connect to the specific database to grant schema privileges
                 $db_pdo = $this->getPostgreSQLConnection($database_name);
                 if ($db_pdo) {
                     // Grant all privileges on all schemas
-                    $db_pdo->exec('GRANT ALL ON SCHEMA public TO ' . $pdo->quote($username));
-                    $db_pdo->exec('GRANT ALL ON ALL TABLES IN SCHEMA public TO ' . $pdo->quote($username));
-                    $db_pdo->exec('GRANT ALL ON ALL SEQUENCES IN SCHEMA public TO ' . $pdo->quote($username));
-                    $db_pdo->exec('GRANT ALL ON ALL FUNCTIONS IN SCHEMA public TO ' . $pdo->quote($username));
+                    $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+                    $db_pdo->exec("GRANT ALL ON SCHEMA public TO $escaped_username");
+                    $db_pdo->exec("GRANT ALL ON ALL TABLES IN SCHEMA public TO $escaped_username");
+                    $db_pdo->exec("GRANT ALL ON ALL SEQUENCES IN SCHEMA public TO $escaped_username");
+                    $db_pdo->exec("GRANT ALL ON ALL FUNCTIONS IN SCHEMA public TO $escaped_username");
                     
                     // Set default privileges for future objects
-                    $db_pdo->exec('ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT ALL ON TABLES TO ' . $pdo->quote($username));
-                    $db_pdo->exec('ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT ALL ON SEQUENCES TO ' . $pdo->quote($username));
-                    $db_pdo->exec('ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT ALL ON FUNCTIONS TO ' . $pdo->quote($username));
+                    $db_pdo->exec("ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT ALL ON TABLES TO $escaped_username");
+                    $db_pdo->exec("ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT ALL ON SEQUENCES TO $escaped_username");
+                    $db_pdo->exec("ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT ALL ON FUNCTIONS TO $escaped_username");
                 }
             } else {
                 // Grant specific privileges
@@ -293,7 +346,9 @@ class pgsqlmgmt {
                 }
                 
                 if (!empty($valid_privileges)) {
-                    $sql = 'GRANT ' . implode(', ', $valid_privileges) . ' ON DATABASE ' . $pdo->quote($database_name) . ' TO ' . $pdo->quote($username);
+                    $escaped_database = '"' . str_replace('"', '""', $database_name) . '"';
+                    $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+                    $sql = 'GRANT ' . implode(', ', $valid_privileges) . " ON DATABASE $escaped_database TO $escaped_username";
                     $pdo->exec($sql);
                 }
             }
@@ -327,11 +382,12 @@ class pgsqlmgmt {
             }
             
             // Drop owned objects
-            $sql = 'DROP OWNED BY ' . $pdo->quote($username) . ' CASCADE';
+            $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+            $sql = "DROP OWNED BY $escaped_username CASCADE";
             $pdo->exec($sql);
             
             // Drop the user
-            $sql = 'DROP USER ' . $pdo->quote($username);
+            $sql = "DROP USER $escaped_username";
             $pdo->exec($sql);
             
             return ['status' => '0', 'msg' => 'Database user deleted successfully'];
@@ -372,12 +428,14 @@ class pgsqlmgmt {
             }
             
             // Revoke all privileges first
-            $sql = 'REVOKE ALL PRIVILEGES ON DATABASE ' . $pdo->quote($database_name) . ' FROM ' . $pdo->quote($username);
+            $escaped_database = '"' . str_replace('"', '""', $database_name) . '"';
+            $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+            $sql = "REVOKE ALL PRIVILEGES ON DATABASE $escaped_database FROM $escaped_username";
             $pdo->exec($sql);
             
             // Grant new privileges
             if (in_array('ALL', $privileges)) {
-                $sql = 'GRANT ALL PRIVILEGES ON DATABASE ' . $pdo->quote($database_name) . ' TO ' . $pdo->quote($username);
+                $sql = "GRANT ALL PRIVILEGES ON DATABASE $escaped_database TO $escaped_username";
                 $pdo->exec($sql);
             } else {
                 $privilege_map = [
@@ -398,7 +456,9 @@ class pgsqlmgmt {
                 }
                 
                 if (!empty($valid_privileges)) {
-                    $sql = 'GRANT ' . implode(', ', $valid_privileges) . ' ON DATABASE ' . $pdo->quote($database_name) . ' TO ' . $pdo->quote($username);
+                    $escaped_database = '"' . str_replace('"', '""', $database_name) . '"';
+                    $escaped_username = '"' . str_replace('"', '""', $username) . '"';
+                    $sql = 'GRANT ' . implode(', ', $valid_privileges) . " ON DATABASE $escaped_database TO $escaped_username";
                     $pdo->exec($sql);
                 }
             }
@@ -502,6 +562,32 @@ class pgsqlmgmt {
         }
     }
     
+    /**
+     * Check if a PostgreSQL user exists
+     * 
+     * @param string $pgUser The PostgreSQL username to check
+     * @return array Result with exists boolean or error message
+     */
+    public function checkUserExists($pgUser) {
+        try {
+            $pdo = new PDO("pgsql:host={$this->db_host};port={$this->db_port};dbname=postgres", 
+                          $this->root_user, $this->root_password);
+            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
+            
+            $stmt = $pdo->prepare("SELECT 1 FROM pg_user WHERE usename = :username");
+            $stmt->bindParam(':username', $pgUser);
+            $stmt->execute();
+            
+            $exists = $stmt->fetch() !== false;
+            
+            return ['status' => '0', 'exists' => $exists];
+            
+        } catch (Exception $e) {
+            error_log("PostgreSQL checkUserExists error: " . $e->getMessage());
+            return ['status' => '1', 'msg' => 'Error checking user existence: ' . $e->getMessage()];
+        }
+    }
+
     /**
      * List database users that a specific user can manage
      * 
